#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-serializer
version:              0.3.5
visibility:           public
id:                   data-serializer-0.3.5-5ZmbnIAvAIu3BQBVEFQ527
key:                  data-serializer-0.3.5-5ZmbnIAvAIu3BQBVEFQ527
license:              BSD-3-Clause
copyright:            2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-serializer
synopsis:             Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.

category:             Data
abi:                  892c50465ea5d70c8ee39accdc90969c
exposed:              True
exposed-modules:      Data.Deserializer Data.Serializer
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-serializer-0.3.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-serializer-0.3.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-serializer-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-serializer
hs-libraries:         HSdata-serializer-0.3.5-5ZmbnIAvAIu3BQBVEFQ527
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    data-endian-0.1.1-AArotBb6YVx66xbeUMCKUi
    parsers-0.12.12-2rKmSnVfzgR3wwIgB7Tg1a
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8

haddock-interfaces:
    /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock

haddock-html:         /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

